@@ -1,7 +1,8 @@
 #pragma once
 #include <QLatin1String>
 
-#define KWIN_PLUGIN_VERSION_STRING "6.4.5"
+#define KWIN_PLUGIN_VERSION_STRING "6.5.0"
+#define PROJECT_VERSION_PATCH 0
 
 #define KWIN_BUILD_DECORATIONS 1
 #define KWIN_BUILD_KCMS 1
@@ -11,8 +12,9 @@
 #define KWIN_BUILD_ACTIVITIES 1
 #define KWIN_BUILD_GLOBALSHORTCUTS 1
 #define KWIN_BUILD_X11 1
+#define KWIN_BUILD_QACCESSIBILITYCLIENT 1
 constexpr QLatin1String KWIN_CONFIG("kwinrc");
-constexpr QLatin1String KWIN_VERSION_STRING("6.4.5");
+constexpr QLatin1String KWIN_VERSION_STRING("6.5.0");
 constexpr QLatin1String XCB_VERSION_STRING("1.17.0");
 constexpr QLatin1String KWIN_KILLER_BIN("/usr/libexec/kwin_killer_helper");
 constexpr QLatin1String LIBEXEC_DIR("/usr/libexec");
@@ -22,13 +24,10 @@ constexpr QLatin1String LIBEXEC_DIR("/usr/libexec");
 #define HAVE_GBM_BO_CREATE_WITH_MODIFIERS2 1
 #define HAVE_MEMFD 1
 #define HAVE_SCHED_RESET_ON_FORK 1
-#define HAVE_ACCESSIBILITY 0
 #define HAVE_XKBCOMMON_NO_SECURE_GETENV 1
 #define HAVE_XWAYLAND_ENABLE_EI_PORTAL 1
-#define HAVE_GLX 0
 #define HAVE_DL_LIBRARY 0
-#define HAVE_WL_DISPLAY_SET_DEFAULT_MAX_BUFFER_SIZE 1
-#define HAVE_WL_FIXES 1
+#define HAVE_LIBDRM_FAUX 1
 
 constexpr QLatin1String XWAYLAND_SESSION_SCRIPTS("/etc/xdg/Xwayland-session.d");
 
